@@ -2,7 +2,7 @@
 Date         : 2022-10-25 15:44:41
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2023-11-28 14:18:01
+LastEditTime : 2023-12-01 11:24:46
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\__init__.py
@@ -12,5 +12,5 @@ Copyright (c) 2022 by BDFD, All Rights Reserved.
 from .format import _data_conversion, _format_data
 from .eda import _data_mining, _data_preprocess, _standardization, _feature_selection
 # from execdata.standardization import encode
-from .model import _model_evaluate
+from .model import _model_evaluate, _regression_model
 from .graph import _data_analysis_graph, _data_mining_graph, _linear_regression_type_graph, _logistic_regression_type_graph
